try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="82692b90-7bd3-4158-84f3-870943f07d86",e._sentryDebugIdIdentifier="sentry-dbid-82692b90-7bd3-4158-84f3-870943f07d86")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.06.04-5fd875e"}}catch(e){}}(),exports.id=4128,exports.ids=[4128],exports.modules={"./src/commands/uninstall-shell-integration.ts":(e,n,t)=>{t.r(n),t.d(n,{handleUninstallShellIntegration:()=>f});var i=t("node:fs"),l=t("node:os"),o=t("node:path"),s=t.n(o),d=t("./src/console-io.ts");const r='eval "$(~/.local/bin/agent shell-integration zsh)"',a='eval "$(~/.local/bin/cursor-agent shell-integration zsh)"';function f(){const e=s().join((0,l.homedir)(),".zshrc");try{let n="";try{n=(0,i.readFileSync)(e,"utf8")}catch(e){if("ENOENT"===e.code)return void(0,d.p2)("~/.zshrc file not found. Shell integration is not installed.");throw e}if(!n.includes(r)&&!n.includes(a))return void(0,d.p2)("Shell integration is not installed in ~/.zshrc");const t=n.split("\n"),l=t.filter((e=>e.trim()!==r&&e.trim()!==a));t[0]!==r&&t[0]!==a||""!==t[1]||l.shift();const o=l.join("\n");(0,i.writeFileSync)(e,o,"utf8"),(0,d.p2)("Shell integration uninstalled successfully!"),(0,d.p2)("Please restart your terminal for changes to take effect.")}catch(e){(0,d.p2)(`Failed to uninstall shell integration: ${String(e)}`),process.exit(1)}}}};